#[non_exhaustive]pub enum RenderingRotation {
NoRotation,
Rotate90,
Rotate180,
Rotate270,
}Expand description
This enum describes the rotation that should be applied to the contents rendered by the software renderer.
Argument to be passed in SoftwareRenderer::set_rendering_rotation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoRotation
No rotation
Rotate90
Rotate 90° to the right
Rotate180
180° rotation (upside-down)
Rotate270
Rotate 90° to the left
Implementations