RepaintBufferType

Enum RepaintBufferType 

pub enum RepaintBufferType {
    NewBuffer,
    ReusedBuffer,
    SwappedBuffers,
}
This enum describes which parts of the buffer passed to the SoftwareRenderer may be re-used to speed up painting.

Variants



NewBuffer

The full window is always redrawn. No attempt at partial rendering will be made.



ReusedBuffer

Only redraw the parts that have changed since the previous call to render().

This variant assumes that the same buffer is passed on every call to render() and that it still contains the previously rendered frame.



SwappedBuffers

Redraw the part that have changed since the last two frames were drawn.

This is used when using double buffering and swapping of the buffers.