DrawTextureArgs

Struct DrawTextureArgs 

#[non_exhaustive]
pub struct DrawTextureArgs { pub colorize: Option<Color>, pub alpha: u8, pub dst_x: isize, pub dst_y: isize, pub dst_width: usize, pub dst_height: usize, pub rotation: RenderingRotation, pub tiling: Option<TilingInfo>, /* private fields */ }
Available on crate feature experimental only.
This structure describes the properties of a texture for blending with TargetPixelBuffer::draw_texture.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
colorize: Option<Color>

When set, the source is to be considered as an alpha map (so for ARGB texture, the RGB component will be ignored). And the given color is to be blended using the alpha value of the texture.

alpha: u8

A value between 0 and 255 that specifies the alpha value of the texture. If colorize is set, this value can be ignored as the alpha would be part of the colorize value. A value of 0 would mean that the texture is fully transparent (so nothing is drawn), and a value of 255 would mean fully opaque.

dst_x: isize

The x position in the destination buffer to draw the texture at

dst_y: isize

The y position in the destination buffer to draw the texture at

dst_width: usize

The width of the image in the destination. The image should be scaled to fit.

dst_height: usize

The height of the image in the destination. The Image should be scaled to fit

rotation: RenderingRotation

the rotation to apply to the texture

tiling: Option<TilingInfo>

If the texture is to be tiled, this contains the information about the tiling

Implementations

Source

impl DrawTextureArgs

pub fn source(&self) -> TextureData<'_>

Returns the source image data for this texture