PhysicalRegion

Struct PhysicalRegion 

pub struct PhysicalRegion { /* private fields */ }
Represents a rectangular region on the screen, used for partial rendering.

The region may be composed of multiple sub-regions.

Implementations

Source

impl PhysicalRegion

pub fn bounding_box_size(&self) -> PhysicalSize

Returns the size of the bounding box of this region.

pub fn bounding_box_origin(&self) -> PhysicalPosition

Returns the origin of the bounding box of this region.

pub fn iter( &self, ) -> impl Iterator<Item = (PhysicalPosition, PhysicalSize)> + '_

Returns an iterator over the rectangles in this region. Each rectangle is represented by its position and its size. They do not overlap.