#[non_exhaustive]pub struct DrawTextureArgs {
pub colorize: Option<Color>,
pub alpha: u8,
pub dst_x: isize,
pub dst_y: isize,
pub dst_width: usize,
pub dst_height: usize,
pub rotation: RenderingRotation,
pub tiling: Option<TilingInfo>,
/* private fields */
}experimental only.Expand description
This structure describes the properties of a texture for blending with TargetPixelBuffer::draw_texture.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.colorize: Option<Color>When set, the source is to be considered as an alpha map (so for ARGB texture, the RGB component will be ignored). And the given color is to be blended using the alpha value of the texture.
alpha: u8A value between 0 and 255 that specifies the alpha value of the texture.
If colorize is set, this value can be ignored as the alpha would be part of the colorize value.
A value of 0 would mean that the texture is fully transparent (so nothing is drawn),
and a value of 255 would mean fully opaque.
dst_x: isizeThe x position in the destination buffer to draw the texture at
dst_y: isizeThe y position in the destination buffer to draw the texture at
dst_width: usizeThe width of the image in the destination. The image should be scaled to fit.
dst_height: usizeThe height of the image in the destination. The Image should be scaled to fit
rotation: RenderingRotationthe rotation to apply to the texture
tiling: Option<TilingInfo>If the texture is to be tiled, this contains the information about the tiling