pub struct PhysicalRegion { /* private fields */ }Expand description
Represents a rectangular region on the screen, used for partial rendering.
The region may be composed of multiple sub-regions.
Implementations
Sourceimpl PhysicalRegion
impl PhysicalRegion
Sourcepub fn bounding_box_size(&self) -> PhysicalSize
pub fn bounding_box_size(&self) -> PhysicalSize
Returns the size of the bounding box of this region.
Sourcepub fn bounding_box_origin(&self) -> PhysicalPosition
pub fn bounding_box_origin(&self) -> PhysicalPosition
Returns the origin of the bounding box of this region.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (PhysicalPosition, PhysicalSize)> + '_
pub fn iter( &self, ) -> impl Iterator<Item = (PhysicalPosition, PhysicalSize)> + '_
Returns an iterator over the rectangles in this region. Each rectangle is represented by its position and its size. They do not overlap.